@@ -1,4 +1,4 @@
-use lenna_cli::{images_in_path, plugins, zip_images};
+use lenna_cli::{images_in_path, write_to_path, plugins};
 use lenna_core::{Config, Pipeline};
 use std::env;
 use structopt::StructOpt;
@@ -86,35 +86,7 @@ fn main() {
                 false => {
                     let ext = args.out_path.extension().unwrap().to_str().unwrap();
                     img.name = args.out_path.file_stem().unwrap().to_str().unwrap().into();
-                    img.path = args.out_path.parent().unwrap().to_str().unwrap().into();
-                    match ext {
-                        "zip" => {
-                            img.name = format!("{}.jpg", img.name);
-                            let images = vec![&mut img];
-                            let file = std::fs::File::create(&args.out_path).unwrap();
-                            zip_images(
-                                images,
-                                image::ImageOutputFormat::Jpeg(80),
-                                file,
-                                zip::CompressionMethod::DEFLATE,
-                            )
-                            .unwrap();
-                        }
-                        "png" | "PNG" => {
-                            lenna_core::io::write::write_to_file(
-                                &img,
-                                image::ImageOutputFormat::Png,
-                            )
-                            .unwrap();
-                        }
-                        _ => {
-                            lenna_core::io::write::write_to_file(
-                                &img,
-                                image::ImageOutputFormat::Jpeg(80),
-                            )
-                            .unwrap();
-                        }
-                    }
+                    write_to_path(img, out_path, ext.to_string());
                 }
             };
         }
